package be.iminds.ilabt.jfed.git;

import be.iminds.ilabt.jfed.util.KeyUtil;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.security.PrivateKey;
import java.util.Collections;
import java.util.List;

/**
 * Fallback git auth preferences: authenticate everything with the same private SSH key.
 */
public class SingleSshGitAuthPreferences implements GitAuthPreferences {
    @Nonnull private final String privateSshPemKey;

    public SingleSshGitAuthPreferences(@Nonnull String privateSshPemKey) {
        this.privateSshPemKey = privateSshPemKey;
    }
    public SingleSshGitAuthPreferences(@Nonnull PrivateKey privateSshKey) {
        this.privateSshPemKey = new String(KeyUtil.privateKeyToAnyPem(privateSshKey));
    }

    @Nonnull
    @Override
    public List<GitAuthMethod> getGitAuthMethodAvailable(String repoUrl) {
        return Collections.singletonList(GitAuthMethod.SSH);
    }

    @Override
    public boolean hasAuth(String repoUrl) {
        return getRepoUrlGitAuthMethod(repoUrl).contains(GitAuthMethod.SSH);
    }

    @Nullable
    @Override
    public GitAuth getGitAuth(String repoUrl, GitAuthMethod... allowedMethods) {
        for (GitAuthMethod allowedMethod : allowedMethods) {
            if (allowedMethod == GitAuthMethod.SSH)
                return getGitAuthSsh(repoUrl);
        }
        return null;
    }

    @Nullable
    @Override
    public GitAuthSsh getGitAuthSsh(String repoUrl) {
        return new GitAuthSsh(repoUrl, privateSshPemKey);
    }

    @Nullable
    @Override
    public GitAuthUserPass getGitAuthUserPass(String repoUrl) {
        return null;
    }
}
